@@ -237,13 +237,13 @@ class Strategy52WHigh(Strategy):
         return df
     
     def screener(self, formatMessage = True):
-        result = []
+        result = self.saved_data.get('result', [])
         ticker_list = self.getTickerList()
         pending_tickers = self.getTickerList(pending = True)
         processed_tickers = self.getTickerList(processed = True)
         if len(pending_tickers) != 0:
             if self.save:
-                sample_tickers = random.sample(pending_tickers, min(50, len(pending_tickers)))
+                sample_tickers = random.sample(pending_tickers, min(40, len(pending_tickers)))
             else:
                 sample_tickers = pending_tickers
             for ticker in sample_tickers:
@@ -262,19 +262,21 @@ class Strategy52WHigh(Strategy):
                         })
                 except:
                     pass
+                processed_tickers.append(ticker)
 
-            # Save to file
-            result = self.saved_data.get('result', []) + result
-            processed_tickers = processed_tickers + sample_tickers
-            data = {
-                'processed_tickers': processed_tickers + sample_tickers,
-                'result' : result
-            }
-            self.saveToFile(data)
+                # Save to file
+                #result = self.saved_data.get('result', []) + result
+                #processed_tickers = processed_tickers + sample_tickers
+                data = {
+                    'processed_tickers': processed_tickers,
+                    'result' : result
+                }
+                self.saveToFile(data)
             if len(processed_tickers) < len(ticker_list):
                 return None
         else:
-            result = self.saved_data.get('result', [])
+            return None
+            #result = self.saved_data.get('result', [])
         
         if formatMessage:
             message = '<b>52w High breached </b>\n\n'
